isochrones
==========
.. image:: https://zenodo.org/badge/6253/timothydmorton/isochrones.svg   
    :target: http://dx.doi.org/10.5281/zenodo.16304

Provides simple interface for interacting with stellar model grids.

Installation
-----------

Install with ``pip install isochrones`` or by cloning the repository
and running ``python setup.py install``.

Depends on normal scientific libraries (e.g. `numpy`, `pandas`, etc.),
as can easily be installed trouble-free via, e.g., the anaconda python distribution.

For usage, `read the documentation <http://isochrones.rtfd.org>`_ or
check out the `demo notebook <http://nbviewer.ipython.org/github/timothydmorton/isochrones/blob/master/notebooks/demo.ipynb>`_.

